function nf = UR_URBAN_sim_ICRA_exp1(t_max,ss,s_name,f_data,f_policy)
% UR_URBAN_sim_ICRA_exp1 - ICRA Experiment 1
% On input:
%     t_max (float): max time to simulate
%     ss (int): save session flag (1: yes; 0: no)
%     s_name (string): file name for session data
%     f_data (string): file name with scenario data
%     f_policy (string): name of launch policy function
% On output:
%     nf (int): number of flights scheduled
% Call:
%     clear all
%     rng('default');  % to get repeat result, if necessary
%     UR_URBAN_sim_ICRA_exp1(10,0,[],'sim_exp1_data.txt','UR_A0_policy');
% Author:
%     T. Henderson
%     University of Utah
%     Fall 2019
%

% Set path to tch library
path(path,'C:\Users\user\Documents\MATLAB\tchlib');

% flight manager file name
f_FM = 'UR_flight_manager';

% USS file names
USS(1).name = 'UR_USS_exp1_0';
%USS(2).name = 'UR_USS_exp2';

% Set up roads (two end points, one edge)
roads = UR_gen_roads_fixed3x3;

% Specify launch sites
fid = fopen('LAUNCH_SITES','w');
for e = 1:9  % All vertexes are launch sites
    fprintf(fid,'%d\n',e);
end
fclose(fid);

% Specify land sites
fid = fopen('LAND_SITES','w');
for e = 1:9  % All vertexes are land sites
    fprintf(fid,'%d\n',e);
end
fclose(fid);

t= 0;
while t<t_max&~UR_exit_flag
    t = t + 1
    UR_run_USS(USS,t);
    [airways,flight_plans,flights] = UR_flight_manager(roads,...
        f_data,f_policy);
    if UR_error(flights)
        tch = 0;
    end
end
if ss==1
    UR_save_session_data(s_name);
end
tch = 0;
nf = size(flight_plans,2);
